/*  misc.h - miscellaneous function definitions
 *  Copyright (C) 2000-2003  Jason Jordan <shnutils@freeshell.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 * $Id: misc.h,v 1.14 2003/02/17 04:36:43 jason Exp $
 */

#ifndef __MISC_H__
#define __MISC_H__

#include <stdio.h>
#include "wave.h"

#define NO_CHILD_PID   -740
#define MAX_CHILD_ARGS  256

extern int num_child_args;
extern char *child_args[];

typedef enum {
  CHILD_INPUT,
  CHILD_OUTPUT
} child_types;

#define spawn_input(a,b)  spawn(a,b,CHILD_INPUT)
#define spawn_output(a,b) spawn(a,b,CHILD_OUTPUT)

#define close_and_wait_input(a,b)  close_and_wait(a,b,CHILD_INPUT)
#define close_and_wait_output(a,b) close_and_wait(a,b,CHILD_OUTPUT)

/* run an external program, and sets up two-way communication with that process */
int spawn(FILE **,FILE **,int);

/* close a file descriptor, and wait for a child process if necessary */
void close_and_wait(FILE *,int,int);

/* determines whether a filename contains a '.' in its base file name */
int filename_contains_a_dot(char *);

/* a simple menu system to alter the order in which given input files will be processed */
void alter_file_order(wave_info **,int);

/* generic version printing function - don't use this if you write your own mode modules (unless you want me to take credit for it :) */
void internal_version(void);

/* function to convert a file's length to m:ss or m:ss.ff format */
void length_to_str(wave_info *);

/* replacement snprintf */
void my_snprintf(char *,int,char *,...);

/* functions for building argument lists in format modules */
void arg_add(char *);

/* initialization function for modes that create output formats via -o format */
format_module *output_format_init(int,char **,int *);

#endif
