/*  format_ofr.c - ofr format module
 *  Copyright (C) 2000-2003  Jason Jordan <shnutils@freeshell.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 * $Id: format_ofr.c,v 1.11 2003/02/17 04:10:42 jason Exp $
 */

#include <stdio.h>
#include <string.h>
#include "format.h"
#include "fileio.h"
#include "misc.h"

#define OPTIMFROG "optimfrog"

static FILE *open_for_input(char *,int *);
static FILE *open_for_output(char *,int *);
static int is_our_file(char *);

format_module format_ofr = {
  "ofr",
  "OptimFROG Lossless WAVE Audio Coder",
  "ofr",
  0,
  1,
  OPTIMFROG,
  OPTIMFROG,
  is_our_file,
  open_for_input,
  open_for_output,
  NULL,
  NULL
};

static FILE *open_for_input(char *filename,int *pid)
{
  FILE *input,*output;

  arg_add(OPTIMFROG);
  arg_add("d");
  arg_add(filename);
  arg_add("-");

  *pid = spawn_input(&input,&output);

  if (output)
    fclose(output);

  return input;
}

static FILE *open_for_output(char *filename,int *pid)
{
  FILE *input,*output;

  arg_add(OPTIMFROG);
  arg_add("e");
  arg_add("-");
  arg_add(filename);

  *pid = spawn_output(&input,&output);

  if (input)
    fclose(input);

  return output;
}

static int is_our_file(char *filename)
{
  FILE *file;
  unsigned char buf[5];

  if (NULL == (file = fopen(filename,"rb")))
    return 0;

  if (5 != fread(buf,1,5,file)) {
    fclose(file);
    return 0;
  }
  fclose(file);

  if (0 == tagcmp(buf,"*RIFF"))
    return 1;

  /* it's not a OPTIMFROG */
  return 0;
}
